==> patternfly-java-components-0.3.1.jar: org/patternfly/component/ValidationStatus.java <==
/*
 *  Copyright 2023 Red Hat
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      https://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.patternfly.component;

import java.util.function.Supplier;

import org.patternfly.icon.IconSets;
import org.patternfly.icon.PredefinedIcon;
import org.patternfly.style.Classes;

import static org.patternfly.style.Classes.modifier;

public enum ValidationStatus {

    default_(null, IconSets.fas::minus),

    indeterminate(modifier(Classes.indeterminate), IconSets.fas::minus),

    warning(modifier(Classes.warning), IconSets.fas::exclamationTriangle),

    success(modifier(Classes.success), IconSets.fas::checkCircle),

    error(modifier(Classes.error), IconSets.fas::exclamationCircle),

    ;

    public final String modifier;
    public final Supplier<PredefinedIcon> icon;

    ValidationStatus(String modifier, Supplier<PredefinedIcon> icon) {
        this.modifier = modifier;
        this.icon = icon;
    }

    public Severity asSeverity() {
        //noinspection EnhancedSwitchMigration
        switch (this) {
            case indeterminate:
            case default_:
                return Severity.info;
            case warning:
                return Severity.warning;
            case success:
                return Severity.success;
            case error:
                return Severity.danger;
        }
        return Severity.info;
    }
}

==> patternfly-java-components-0.4.1.jar: org/patternfly/component/ValidationStatus.java <==
/*
 *  Copyright 2023 Red Hat
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      https://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.patternfly.component;

import java.util.function.Supplier;

import org.patternfly.icon.IconSets;
import org.patternfly.icon.PredefinedIcon;
import org.patternfly.style.Classes;
import org.patternfly.style.Status;

import static org.patternfly.style.Classes.modifier;

public enum ValidationStatus {

    default_(Status.info, null, IconSets.fas::minus),

    indeterminate(Status.info, modifier(Classes.indeterminate), IconSets.fas::minus),

    success(Status.success, Status.success.modifier(), IconSets.fas::checkCircle),

    warning(Status.warning, Status.warning.modifier(), IconSets.fas::exclamationTriangle),

    error(Status.danger, modifier(Classes.error), IconSets.fas::exclamationCircle);

    public final Status status;
    public final String modifier;
    public final Supplier<PredefinedIcon> icon;

    ValidationStatus(Status status, String modifier, Supplier<PredefinedIcon> icon) {
        this.status = status;
        this.modifier = modifier;
        this.icon = icon;
    }
}
